package de.trantor.kroll.midp.moneytransfer;

import java.io.*;

import javax.microedition.io.*;
import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import javax.microedition.pki.*;


class TransferThread extends Thread {
	
	Form mainForm = null;
	String data = null;
	Alert alert = null;
	Display display = null;
	
	public TransferThread(String data, Alert alert, Display display, Form mainForm) {
		this.mainForm = mainForm;
		this.display = display;
		this.data = data;
		this.alert = alert;
	}
	
	public void run () {
		HttpsConnection conn = null;
		InputStream is = null;
		StringBuffer buffer = new StringBuffer();

		String[] results = null;

		try {
			conn = (HttpsConnection) Connector.open("https://127.0.0.1/ueberweisung?midlet-command=sendData&data=" + data);
			conn.setRequestMethod(HttpsConnection.GET);
			conn.setRequestProperty("User-Agent", "UeberweisungsMIDlet Profile/MIDP-2.0 Configuration/CLDC-1.0");

			SecurityInfo info = conn.getSecurityInfo();
			Certificate c = info.getServerCertificate();
			String issuer = c.getIssuer();
			String type = c.getType();
			String alg = c.getSigAlgName();
			String ver = c.getVersion();
			
			is = conn.openDataInputStream();

			int ch;
			while ((ch = is.read()) != -1) {
				buffer.append((char) ch);
			}
			
			if (buffer.toString().equals("ERROR")) {
				throw new IOException("Error saving Data on Server.");
			}

			alert.setString(alert.getString() + "\nZertifikatsinfo: \nHerausgegeben von: " + issuer +"\nVersion: " + ver + "\nAlgorithmus: " + alg + "\nTyp: " + type);
			display.setCurrent(alert, mainForm);

		}
		catch (IOException e) {
			alert = new Alert("Verbindungsfehler:");
			alert.setString("Fehler beim Aufbau der Verbindung. Grund: " + e.getMessage());
			display.setCurrent(alert, mainForm);
		}
		finally {
			if (is != null) {
				try {
					is.close();
				}
				catch (IOException ex) {}
			}
			if (conn != null) {
				try {
					conn.close();
				}
				catch (IOException ex) {}
			}
		}
	}
}

class Usage extends TextBox implements CommandListener {

	static final Command okCommand = new Command("OK", Command.BACK, 1);
	static final Command clearCommand = new Command("Lschen", Command.SCREEN, 2);

	MoneyTransfer moneyTransfer;

	public Usage(MoneyTransfer moneyTransfer) {
		super("Verwendungszweck", "Kein Verwendungszweck", 50, TextField.ANY);
		this.moneyTransfer = moneyTransfer;

		addCommand(okCommand);
		addCommand(clearCommand);
		setCommandListener(this);
	}

	public String getUsage() {
		return getString();
	}

	public void commandAction(Command c, Displayable d) {
		if (c == clearCommand) {
			setString("");
		}
		else if (c == okCommand) {
			moneyTransfer.back();
		}
	}
}

public class MoneyTransfer extends MIDlet implements CommandListener {

	static final Command sendCommand = new Command("Senden", Command.SCREEN, 2);
	static final Command exitCommand = new Command("Beenden", Command.SCREEN, 1);
	static final Command reasonCommand = new Command("Zweck", Command.SCREEN, 2);

	Form mainForm = new Form("berweisungs MIDlet");

	TextField name = new TextField("Name des Empfngers", "", 20, TextField.ANY);
	TextField accountNo = new TextField("Kontonummer", "", 12, TextField.NUMERIC);
	TextField bankNumber = new TextField("BLZ", "", 12, TextField.NUMERIC);
	TextField euros = new TextField("Euro", "", 6, TextField.NUMERIC);
	TextField cents = new TextField("Cent", "", 2, TextField.NUMERIC);
	TextField tan = new TextField("TAN", "", 6, TextField.NUMERIC);

	Usage transferReason = new Usage(this);
	Display display;

	String data = "NO DATA";

	public MoneyTransfer() {
		mainForm.append(name);
		mainForm.append(accountNo);
		mainForm.append(bankNumber);
		mainForm.append(euros);
		mainForm.append(cents);
		mainForm.append(tan);

		mainForm.addCommand(reasonCommand);
		mainForm.addCommand(sendCommand);
		mainForm.addCommand(exitCommand);
		mainForm.setCommandListener(this);
	}

	public void startApp() {
		display = Display.getDisplay(this);
		display.setCurrent(mainForm);
	}

	public void resetTransferInformation() {
		name.setString("");
		accountNo.setString("");
		euros.setString("");
		bankNumber.setString("");
		cents.setString("");
		transferReason.setString("");
		tan.setString("");
	}

	public void sendTransferInformation() throws IOException {

		Alert alert = new Alert("Gesendet:");
		alert.setString(
			"berweisungsauftrag:\n EURO "
				+ euros.getString()
				+ "."
				+ cents.getString()
				+ "\nauf Konto-Nr. "
				+ accountNo.getString() +", BLZ: " + bankNumber.getString() 
				+ "\nvon "
				+ name.getString()
				+ "\n\nVerwendungszweck:\n"
				+ transferReason.getUsage());


		String data = name.getString() + ";" + bankNumber.getString() + ";" + accountNo.getString() + ";" + euros.getString() + ";" + cents.getString() + ";" + tan.getString() + ";" + transferReason.getUsage();
		System.out.println(data);
		
		while (true) {
			int idx = data.indexOf(' ');
			String tmp1 = data.substring(0, idx);
			String tmp2 = data.substring(idx+1, data.length());
			data = tmp1 + "%20" + tmp2;

			if (data.indexOf(' ') == -1)
				break;
		}

		Alert progress = new Alert("Verbinde...");
		progress.setString("Stelle Verbindung mit dem Server her.");
		progress.setTimeout(Alert.FOREVER);
		display.setCurrent(progress);

		new TransferThread(data, alert, display, mainForm).start();

		resetTransferInformation();
	}

	public void pauseApp() {
	}

	public void destroyApp(boolean unconditional) {
	}

	public void back() {
		display.setCurrent(mainForm);
	}

	public void commandAction(Command c, Displayable d) {
		if (c == exitCommand) {
			notifyDestroyed();
		}
		else if (c == sendCommand) {
			try {
				sendTransferInformation();
			}
			catch (IOException ex) {
				ex.printStackTrace();
			}
		}
		else if (c == reasonCommand) {
			display.setCurrent(transferReason);
		}
	}
}
